import configparser
import os
from PIL import Image

# Change working directory to script directory
os.chdir(os.path.dirname(os.path.abspath(__file__)))

opts_parser = configparser.ConfigParser()
with open('options.ini', 'r', encoding='utf-8') as opts_file:
    opts_parser.read_file(opts_file)
horiz_res = opts_parser.getint('image options', 'horizontal resolution')
vert_res = opts_parser.getint('image options', 'vertical resolution')
angle_rot = opts_parser.getint('image options', 'angle of rotation')


def display_menu():
    print(24 * '-', 'MENU', 24 * '-')
    print('1. Resize images:', opts_parser['image options']['resize images'])
    print('2. Resolution:', str(horiz_res) + 'x' + str(vert_res)
          if opts_parser['image options']['resize images'].upper() == 'YES' else 'n/a')
    print('3. Preserve aspect ratio:',
          opts_parser['image options']['preserve aspect ratio'])
    print('4. Grayscale:', opts_parser['image options']['grayscale'])
    print('5. Rotate images:', opts_parser['image options']['rotate images'])
    print('6. Angle of rotation:', str(angle_rot) +
          '°' if opts_parser['image options']['rotate images'].upper() == 'YES' else 'n/a')
    print('7. Process images')
    print('8. Save options to file')
    print('9. Exit')
    print(54 * '-')


def image_proc(img_data):
    # Process images according to options chosen by user
    if (opts_parser['image options']['resize images'].upper() == 'YES'
            and opts_parser['image options']['preserve aspect ratio'].upper() == 'YES'):
        vert_res_aspect = horiz_res * img_data.height // img_data.width
        img_data = img_data.resize(
            (horiz_res, vert_res_aspect), Image.Resampling.LANCZOS)
    elif opts_parser['image options']['resize images'].upper() == 'YES':
        img_data = img_data.resize(
            (horiz_res, vert_res), Image.Resampling.LANCZOS)
    if opts_parser['image options']['grayscale'].upper() == 'YES':
        img_data = img_data.convert('L')
    if opts_parser['image options']['rotate images'].upper() == 'YES':
        img_data = img_data.rotate(
            0 - angle_rot, Image.Resampling.BICUBIC, expand=True)
    return img_data


def toggle_yes_no(tog_state):
    # Change toggle state
    tog_state = 'yes' if tog_state.upper() == 'NO' else 'no'
    return tog_state


menu_loop = True
while menu_loop:
    # Clear screen
    _ = os.system('cls') if os.name == 'nt' else os.system('clear')
    display_menu()
    menu_opt = input('Enter a number then press enter: ')
    if menu_opt == '1':
        opts_parser['image options']['resize images'] = toggle_yes_no(
            opts_parser['image options']['resize images'])
    elif menu_opt == '2':
        horiz_res = int(
            input('Enter the horizontal resolution then press enter: '))
        vert_res = int(
            input('Enter the vertical resolution then press enter: '))
    elif menu_opt == '3':
        opts_parser['image options']['preserve aspect ratio'] = toggle_yes_no(
            opts_parser['image options']['preserve aspect ratio'])
    elif menu_opt == '4':
        opts_parser['image options']['grayscale'] = toggle_yes_no(
            opts_parser['image options']['grayscale'])
    elif menu_opt == '5':
        opts_parser['image options']['rotate images'] = toggle_yes_no(
            opts_parser['image options']['rotate images'])
    elif menu_opt == '6':
        angle_rot = int(
            input('Enter the angle of rotation then press enter: '))
    elif menu_opt == '7':
        loop_success = 0
        for entry in os.scandir(opts_parser['folder paths']['input']):
            if not entry.name.startswith('.') and entry.is_file():
                with Image.open(
                        os.path.join(opts_parser['folder paths']['input'], entry.name)) as img_file:
                    img_file = image_proc(img_file)
                    img_file.save(os.path.join(
                        opts_parser['folder paths']['output'], 'imgedited_' + entry.name), quality=95)
                    loop_success += 1
        if loop_success > 0:
            print(input('\nImage processing complete, press enter to continue.'))
        else:
            print(input('\nInput folder is empty, press enter to continue.'))
    elif menu_opt == '8':
        opts_parser['image options']['horizontal resolution'] = str(horiz_res)
        opts_parser['image options']['vertical resolution'] = str(vert_res)
        opts_parser['image options']['angle of rotation'] = str(angle_rot)
        with open('options.ini', 'w', encoding='utf-8') as opts_file_out:
            opts_parser.write(opts_file_out)
        print(input('\nOptions saved to file, press enter to continue.'))
    elif menu_opt == '9':
        print('\nGoodbye.')
        menu_loop = False
    else:
        print('Please enter a valid number.')
